@@ -878,6 +878,18 @@ c_common_handle_option (size_t scode, const char *arg, int value)
       sparc_fix_b2bst = value;
       break;
 
+    case OPT_mfix_gr712rc:
+      sparc_fix_gr712rc = value;
+      break;
+
+    case OPT_mfix_ut700:
+      sparc_fix_ut700 = value;
+      break;
+
+    case OPT_mfix_tn0013:
+      sparc_fix_tn0013 = value;
+      break;
+
     case OPT_mfpstore_branch_slots:
       fpstore_branch_slots = value;
       break;
